package com.muyu.common.core.enums;

import java.util.Arrays;

/**
 * @Author: wangxinyuan
 * @Date: 2024/8/5 下午7:47
 */
public enum SysPayType {

    ALI_PAY("aliPay","支付宝"),
    WECHAT_PAY("wechatPay","微信支付"),
    JD_PAY("jdPay","京东支付"),
    ;

    private final String code;

    private final String info;

    SysPayType (String code, String info) {
        this.code = code;
        this.info = info;
    }

    public String getCode(){
        return code;
    }

    public String getInfo(){
        return info;
    }

    /**
     * 鉴别Code是否合法
     * @param code 传code
     * @return 如果存在code则返回true，不存在则返回false
     */
    public static boolean isCode(String code){
        return Arrays.stream(values())
                .map(SysPayType::getCode)
                .anyMatch(s -> s.equals(code));
    }

    /**
     * 通过code获取支付渠道
     * @param code code编码
     * @return 支付渠道
     */
    public static String getInfoByCode(String code){
        return Arrays.stream(values())
                .filter(s -> s.getCode().equals(code))
                .findFirst()
                .map(SysPayType::getInfo)
                .orElseGet(() -> "-");
    }


}
